You were provided with the following documents:
- **core documents** - these are already a reviewed documents which are part of official project documentation.
- **source documents** (called also **sources**) - these are not part of official project documentation and they will be deleted after your task is completed.

{% if core_documents %}
There are the following **core documents** available during this session:
{% for document in core_documents %}
- {{ document.id }} - {{ document.name }}
{% endfor %}
{% else %}
There are no **core documents** available during this session.
{% endif %}

{% if new_documents %}
There are the following **source documents** (called also **sources**) available during this session:
{% for document in new_documents %}
- {{ document.id }} - {{ document.name }}
{% endfor %}
{% else %}
There are no **source documents** (called also **sources**) available during this session.
{% endif %}

There won't be more **core documents** and **source documents** provided during this conversation, however **new core documents** may be provided.
