During this session the followiing **new core documents** were created:
{% for document in new_core_documents %}
- {{ document.id }} - {{ document.name }}
{% endfor %}

There won't be more documents provided during this session.
